package main

import (
	"flag"
	"os"
	"os/signal"
	"syscall"

	"git.ctrlz.es/mgdelacroix/birthdaybot/model"
	"git.ctrlz.es/mgdelacroix/birthdaybot/server"
	"github.com/charmbracelet/log"
)

func configureLogger(config *model.Config, logger *log.Logger) {
	// ToDo: apply config to logger
}

func main() {
	configFlag := flag.String("config", "birthdaybot.yml", "path to the configuration file")
	flag.Parse()

	logger := log.New(os.Stderr)

	config, err := model.ReadConfig(*configFlag)
	if err != nil {
		logger.Error("error reading config", "configPath", *configFlag, "error", err)
		os.Exit(1)
	}

	if err := config.IsValid(); err != nil {
		logger.Error("invalid config", "configPath", *configFlag, "error", err)
		os.Exit(1)
	}

	configureLogger(config, logger)

	srv, err := server.New(
		server.WithLogger(logger),
		server.WithConfig(config),
	)
	if err != nil {
		logger.Error("error creating server", "error", err)
		os.Exit(1)
	}

	c := make(chan os.Signal, 1)
	signal.Notify(c, syscall.SIGINT, syscall.SIGTERM)

	srv.Start()
	s := <-c
	srv.Logger.Info("received signal, stopping", "signal", s)
	srv.Stop()
}
